%define modname lxml
# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov %{python_sitearch}/.*\\.so\\|%{python3_sitearch}/.*\\.so

Name:           python-%{modname}
URL:            http://codespeak.net/lxml/
Summary:        A Pythonic binding for the libxml2 and libxslt libraries
Version:        3.8.0
%define subrel 1
Release:        %mkrel 1
License:        BSD
Group:          Development/Python
Source:         https://lxml.de/files/%{modname}-%{version}.tgz
BuildRequires:  pkgconfig(python)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libexslt) 
BuildRequires:  python-cython >= 0.20
BuildRequires:  python-setuptools

%description
lxml is a Pythonic binding for the libxml2 and libxslt libraries. It follows
the ElementTree API as much as possible, building it on top of the native
libxml2 tree. It also extends this API to expose libxml2 and libxslt specific
functionality, such as XPath, Relax NG, XML Schema, XSLT, and c14n.

%package -n python3-%{modname}
Summary:        A Pythonic binding for the libxml2 and libxslt libraries
Group:          Development/Python
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-setuptools

%description -n python3-%{modname}
lxml is a Pythonic binding for the libxml2 and libxslt libraries. It follows
the ElementTree API as much as possible, building it on top of the native
libxml2 tree. It also extends this API to expose libxml2 and libxslt specific
functionality, such as XPath, Relax NG, XML Schema, XSLT, and c14n.

%package docs
Summary:        Documentation for %{name}
Group:          Documentation
BuildArch:      noarch
%description docs
This package provides the documentation for %{name}, e.g. the API as html.

%prep
%setup -q -n %{modname}-%{version}
# remove the C extension so that it will be rebuilt using the latest Cython
rm -f src/lxml/lxml.etree.c
rm -f src/lxml/lxml.etree.h
rm -f src/lxml/lxml.etree_api.h
rm -f src/lxml/lxml.objectify.c

chmod a-x doc/rest2html.py
%{__sed} -i 's/\r//' doc/s5/ui/default/print.css \
    doc/s5/ep2008/atom.rng \
    doc/s5/ui/default/iepngfix.htc

rm -rf %{py3dir}
cp -r . %{py3dir}

%build
CFLAGS="%{optflags}" %{__python2} setup.py build --with-cython

cp src/lxml/lxml.etree.c %{py3dir}/src/lxml
cp src/lxml/lxml.etree.h %{py3dir}/src/lxml
cp src/lxml/lxml.etree_api.h %{py3dir}/src/lxml
cp src/lxml/lxml.objectify.c %{py3dir}/src/lxml

pushd %{py3dir}
CFLAGS="%{optflags}" %{__python3} setup.py build --with-cython
popd

%install
%{__python2} setup.py install --skip-build --no-compile --with-cython --root %{buildroot}

pushd %{py3dir}
%{__python3} setup.py install --skip-build --no-compile --with-cython --root %{buildroot}
popd


%files
%doc PKG-INFO CREDITS.txt CHANGES.txt
%license LICENSES.txt
%{python2_sitearch}/lxml*

%files docs
%doc doc/*

%files -n python3-lxml
%doc PKG-INFO CREDITS.txt CHANGES.txt
%license LICENSES.txt
%{python3_sitearch}/lxml*



%changelog
* Thu Oct 11 2018 bcornec <bcornec> 3.8.0-1.1.mga6
+ Revision: 1319470
- Import from cauldron for calibre update

* Mon Apr 11 2016 philippem <philippem> 3.6.0-1.mga6
+ Revision: 1000204
- update to 3.6.0

* Fri Feb 12 2016 umeabot <umeabot> 3.4.4-3.mga6
+ Revision: 958618
- Mageia 6 Mass Rebuild

* Thu Oct 08 2015 tv <tv> 3.4.4-2.mga6
+ Revision: 887748
- rebuild for python 3.5

* Thu Oct 01 2015 philippem <philippem> 3.4.4-1.mga6
+ Revision: 885552
- update to 3.4.4

* Wed Oct 15 2014 umeabot <umeabot> 3.3.6-4.mga5
+ Revision: 740649
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.3.6-3.mga5
+ Revision: 728968
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.3.6-2.mga5
+ Revision: 688134
- Mageia 5 Mass Rebuild

* Sun Aug 31 2014 philippem <philippem> 3.3.6-1.mga5
+ Revision: 670032
- update to 3.3.6

* Sat May 31 2014 pterjan <pterjan> 3.3.5-2.mga5
+ Revision: 628763
- Rebuild for new Python

* Thu May 08 2014 philippem <philippem> 3.3.5-1.mga5
+ Revision: 621229
- update to 3.3.5, fix mga#13326

* Wed Mar 05 2014 philippem <philippem> 3.3.3-1.mga5
+ Revision: 600040
- Update to 3.3.3

* Fri Dec 27 2013 philippem <philippem> 3.2.4-1.mga4
+ Revision: 560959
- Update to 3.2.4

* Tue Oct 22 2013 umeabot <umeabot> 3.2.3-3.mga4
+ Revision: 543721
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 3.2.3-2.mga4
+ Revision: 498872
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Jul 29 2013 philippem <philippem> 3.2.3-1.mga4
+ Revision: 460668
- Update to 3.2.3

* Wed Jun 12 2013 philippem <philippem> 3.2.1-2.mga4
+ Revision: 442226
- build with cython and add python3
- using pyrex
- new upstream

* Sun Jan 13 2013 umeabot <umeabot> 3.0.1-2.mga3
+ Revision: 379081
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Nov 26 2012 philippem <philippem> 3.0.1-1.mga3
+ Revision: 322181
- Update to 3.0.1

* Sat Sep 29 2012 philippem <philippem> 2.3.6-1.mga3
+ Revision: 300219
- new version 2.3.6

* Sat Sep 08 2012 philippem <philippem> 2.3.5-1.mga3
+ Revision: 290055
- New upstream release 2.3.5

* Sun Jan 15 2012 tv <tv> 2.3.3-2.mga2
+ Revision: 196274
- skip huge doc

* Sun Jan 08 2012 philippem <philippem> 2.3.3-1.mga2
+ Revision: 193263
- Update to 2.3.3.

* Fri Nov 18 2011 philippem <philippem> 2.3.2-1.mga2
+ Revision: 168679
- Update to 2.3.2

* Wed Oct 26 2011 philippem <philippem> 2.3.1-1.mga2
+ Revision: 158300
- new upstream 2.3.1

* Mon Jul 04 2011 ahmad <ahmad> 2.3-1.mga2
+ Revision: 118022
- Update to 2.3

* Thu Feb 10 2011 dmorgan <dmorgan> 2.2.8-2.mga1
+ Revision: 49795
- Fix buildrequires
- Fix buildrequire
- imported package python-lxml


* Sat Oct 30 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.8-2mdv2011.0
+ Revision: 590474
- rebuild for python-2.7
- remove obsolete macros
- clean spec

* Sun Sep 12 2010 Guillaume Rousse <guillomovitch@mandriva.org> 2.2.8-1mdv2011.0
+ Revision: 577727
- update to new version 2.2.8

* Sat Aug 14 2010 Guillaume Rousse <guillomovitch@mandriva.org> 2.2.7-1mdv2011.0
+ Revision: 569670
- update to new version 2.2.7

* Mon Mar 08 2010 Sandro Cazzaniga <kharec@mandriva.org> 2.2.6-1mdv2010.1
+ Revision: 515905
- update to 2.2.6

* Sun Jan 03 2010 Emmanuel Andry <eandry@mandriva.org> 2.2.4-1mdv2010.1
+ Revision: 485956
- New version 2.2.4

* Sat Jul 18 2009 Guillaume Rousse <guillomovitch@mandriva.org> 2.2.2-1mdv2010.0
+ Revision: 397066
- update to new version 2.2.2

* Tue Jun 09 2009 Guillaume Rousse <guillomovitch@mandriva.org> 2.2.1-1mdv2010.0
+ Revision: 384252
- update to new version 2.2.1

* Sun Jan 11 2009 Funda Wang <fwang@mandriva.org> 2.1.5-1mdv2009.1
+ Revision: 328231
- 2.1.5

* Sun Jan 04 2009 Jérôme Soyer <saispo@mandriva.org> 2.1.4-1mdv2009.1
+ Revision: 324272
- New upstream release

* Thu Dec 25 2008 Funda Wang <fwang@mandriva.org> 2.1.2-2mdv2009.1
+ Revision: 318984
- rebuild for new python

* Sat Nov 22 2008 Guillaume Rousse <guillomovitch@mandriva.org> 2.1.2-1mdv2009.1
+ Revision: 305841
- update to new version 2.1.2

* Thu Sep 04 2008 Jérôme Soyer <saispo@mandriva.org> 2.1.1-1mdv2009.0
+ Revision: 280559
- New release

* Wed Jun 18 2008 Thierry Vignaud <tv@mandriva.org> 1.3.2-2mdv2009.0
+ Revision: 225134
- rebuild

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 1.3.2-1mdv2008.1
+ Revision: 136450
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Aug 17 2007 Jérôme Soyer <saispo@mandriva.org> 1.3.2-1mdv2008.0
+ Revision: 64972
- New version 1.3.2


* Tue Dec 12 2006 Götz Waschk <waschk@mandriva.org> 0.9.1-4mdv2007.0
+ Revision: 95235
- this can't be noarch

* Wed Dec 06 2006 Jérôme Soyer <saispo@mandriva.org> 0.9.1-3mdv2007.1
+ Revision: 91594
- Fix build errors
- Rebuild with the new python
- Import python-lxml

* Tue Apr 11 2006 Jerome Soyer <saispo@mandriva.org> 0.9.1-2mdk
- Fix Requires

* Tue Apr 11 2006 Jerome Soyer <saispo@mandriva.org> 0.9.1-1mdk
- Initial release

